@@ -235,7 +235,11 @@ SBMLDocument::~SBMLDocument ()
   if (mInternalValidator != NULL)
     delete mInternalValidator;
   if (mModel != NULL)
+  {
+    // remove from static map, since this object is being deleted
+		SBMLTransforms::clearComponentValues(mModel);
     delete mModel;
+  }
   clearValidators();
 }
 
@@ -1691,7 +1695,7 @@ SBMLDocument::readAttributes (const XMLAttributes& attributes,
     int numxmlns= xmlns->getLength();
     for (int i=0; i < numxmlns; i++)
     {
-      const std::string &uri = xmlns->getURI(i);
+      const std::string& uri = xmlns->getURI(i);
       const SBMLExtension* sbmlext = SBMLExtensionRegistry::getInstance().getExtensionInternal(uri);
 
       if (sbmlext && sbmlext->isEnabled())
